pub trait RandomizedSigner<S> {
// Required method
fn try_sign_with_rng<R>(&self, rng: &mut R, msg: &[u8]) -> Result<S, Error>
where R: TryCryptoRng + ?Sized;
// Provided method
fn sign_with_rng<R>(&self, rng: &mut R, msg: &[u8]) -> S
where R: CryptoRng + ?Sized { ... }
}Expand description
Sign the given message using the provided external randomness source.
Required Methods
Sourcefn try_sign_with_rng<R>(&self, rng: &mut R, msg: &[u8]) -> Result<S, Error>where
R: TryCryptoRng + ?Sized,
fn try_sign_with_rng<R>(&self, rng: &mut R, msg: &[u8]) -> Result<S, Error>where
R: TryCryptoRng + ?Sized,
Attempt to sign the given message, returning a digital signature on success, or an error if something went wrong.
The main intended use case for signing errors is when communicating with external signers, e.g. cloud KMS, HSMs, or other hardware tokens.
Errors
Returns implementation-specific errors in the event signing failed (e.g. KMS or HSM
communication error), or if the provided rng experiences an internal failure.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl RandomizedSigner<Box<FAEST128fSignature>> for FAEST128fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAEST128sSignature>> for FAEST128sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAEST192fSignature>> for FAEST192fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAEST192sSignature>> for FAEST192sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAEST256fSignature>> for FAEST256fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAEST256sSignature>> for FAEST256sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAESTEM128fSignature>> for FAESTEM128fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAESTEM128sSignature>> for FAESTEM128sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAESTEM192fSignature>> for FAESTEM192fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAESTEM192sSignature>> for FAESTEM192sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAESTEM256fSignature>> for FAESTEM256fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<Box<FAESTEM256sSignature>> for FAESTEM256sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST128fSignature> for FAEST128fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST128fSignature> for FAEST128fUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST128sSignature> for FAEST128sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST128sSignature> for FAEST128sUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST192fSignature> for FAEST192fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST192fSignature> for FAEST192fUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST192sSignature> for FAEST192sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST192sSignature> for FAEST192sUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST256fSignature> for FAEST256fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST256fSignature> for FAEST256fUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST256sSignature> for FAEST256sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAEST256sSignature> for FAEST256sUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM128fSignature> for FAESTEM128fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM128fSignature> for FAESTEM128fUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM128sSignature> for FAESTEM128sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM128sSignature> for FAESTEM128sUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM192fSignature> for FAESTEM192fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM192fSignature> for FAESTEM192fUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM192sSignature> for FAESTEM192sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM192sSignature> for FAESTEM192sUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM256fSignature> for FAESTEM256fSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM256fSignature> for FAESTEM256fUnpackedSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM256sSignature> for FAESTEM256sSigningKey
Available on crate feature
randomized-signer only.impl RandomizedSigner<FAESTEM256sSignature> for FAESTEM256sUnpackedSigningKey
Available on crate feature
randomized-signer only.